import { aws_ec2 as ec2, aws_ssm as ssm } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Common properties.
 *
 * @stability stable
 */
export interface CodePipelineBitbucketBuildResultReporterProps {
    /**
     * The VPC in which to run the status reporter.
     *
     * @stability stable
     */
    readonly vpc?: ec2.VpcAttributes;
    /**
     * The SSM parameter (SecureString) that contains the BitBucket access token for reporting build statuses.
     *
     * @default BITBUCKET_UPDATE_BUILD_STATUS_TOKEN
     * @stability stable
     */
    readonly bitbucketAccessToken?: ssm.IStringParameter;
    /**
     * The BitBucket server address.
     *
     * @stability stable
     */
    readonly bitbucketServerAddress: string;
}
/**
 * A construct for reporting CodePipeline build statuses to a BitBucket server using BitBucket REST API.
 *
 * You need to configure SSM parameter BITBUCKET_UPDATE_BUILD_STATUS_TOKEN before using the component.
 *
 * @stability stable
 */
export declare class CodePipelineBitbucketBuildResultReporter extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: CodePipelineBitbucketBuildResultReporterProps);
}
